@@ -1,9 +1,6 @@
 from datetime import datetime
 
-from snakypy.zshpower import __info__
-
-content: str = f"""# Generate by: ZSHPower - D{datetime.today().isoformat()}
-# Version: {__info__["version"]}
+config_content: str = f"""# Generate by: ZSHPower - D{datetime.today().isoformat()}
 # ---------------------------------------------------------------------
 # For more information, see the documentation at:
 # https://github.com/snakypy/zshpower#configuration-file
@@ -228,6 +225,7 @@ version.micro.enable = true
 [package]
 enable = false
 symbol = "\\uf8d6"
+display = ["python", "node", "rust", "scala", "crystal", "helm"]
 color = "red"
 prefix.color = "negative"
 prefix.text = "is"
