@@ -1,9 +1,10 @@
 from subprocess import run
 
+from snakypy.zshpower.config.base import Base
 from snakypy.zshpower.prompt.sections.utils import Version
 
 
-class Deno(Version):
+class Deno(Version, Base):
     # 🦕
     def __init__(self):
         super(Deno, self).__init__()
@@ -14,11 +15,7 @@ class Deno(Version):
     ) -> str:
         return super().get(config, reg_version, key=key, ext=ext, space_elem=space_elem)
 
-    def set_version(self, key="deno", action=None) -> bool:
-        version = run("deno -V 2>&1", capture_output=True, shell=True, text=True)
-
-        if version.returncode != 127 and version.returncode != 1:
-            version_format = version.stdout.split()[1]
-            return super().set(version_format, key, action)
-
-        return False
+    def set_version(self, exec_="deno", key="deno", action=None) -> bool:
+        command = run("deno -V", capture_output=True, shell=True, text=True)
+        version = command.stdout.split()[1]
+        return super().set(command, version, exec_, key, action)
