@@ -1,9 +1,10 @@
 from subprocess import run
 
+from snakypy.zshpower.config.base import Base
 from snakypy.zshpower.prompt.sections.utils import Version
 
 
-class Golang(Version):
+class Golang(Version, Base):
     def __init__(self):
         super(Golang, self).__init__()
         self.extensions = (".go",)
@@ -15,11 +16,7 @@ class Golang(Version):
     ) -> str:
         return super().get(config, reg_version, key=key, ext=ext, space_elem=space_elem)
 
-    def set_version(self, key="golang", action=None) -> bool:
-        version = run("go version", capture_output=True, shell=True, text=True)
-
-        if not version.stderr.replace("\n", ""):
-            version_format = version.stdout.replace("go", "").split(" ")[2]
-            return super().set(version_format, key, action)
-
-        return False
+    def set_version(self, exec_="go", key="golang", action=None) -> bool:
+        command = run("go version", capture_output=True, shell=True, text=True)
+        version = command.stdout.replace("go", "").split(" ")[2]
+        return super().set(command, version, exec_, key, action)
